import { PrismaClient, User } from '@prisma/client';
import express from 'express';
import http from 'http';
import { Server } from 'socket.io';
import dotenv from 'dotenv';

dotenv.config();
const prisma = new PrismaClient();

const app = express();
const server = http.createServer(app);
const io = new Server(server, {
    cors: {
        origin: '*',
    }
});

app.get('/', (req: express.Request, res: express.Response) => {
    res.send('Hello World!');
});

io.on('connection', (socket) => {
    console.log('new client connected');
    socket.on('disconnect', () => {
        console.log('client disconnected');
    });

    socket.on('register', (username: string, password: string) => {
        prisma.user.create({
            data: {
                username: username,
                password: password
            }
        }).then((user) => {
            console.log('created user:', user);
        }).catch((error) => {
            console.error('error creating user:', error);
        });
    });
});

const PORT = process.env.SERVER_PORT || 3000;

server.listen(PORT, () => {
    console.log(`listening on *:${PORT}`);
});